@@ -20,18 +20,18 @@
 
 #include <qvariant.h> // HP-UX compiler need this here
 #include "widgetfactory.h"
-#include <widgetdatabase.h>
+#include "widgetdatabase.h"
 #include "metadatabase.h"
 #include "mainwindow.h"
-#include "formwindow.h"
 #include "pixmapchooser.h"
 #include "layout.h"
 #include "listboxeditorimpl.h"
 #include "listvieweditorimpl.h"
 #include "iconvieweditorimpl.h"
-#include "formwindow.h"
 #include "multilineeditorimpl.h"
 #include "widgetinterface.h"
+#include "command.h"
+#include "formwindow.h"
 #ifndef QT_NO_TABLE
 #include "tableeditorimpl.h"
 #endif
@@ -47,6 +47,7 @@
 #ifndef QT_NO_SQL
 #include <qdatatable.h>
 #endif
+#include <qwidgetstack.h>
 #include <qdatetimeedit.h>
 #include <qlineedit.h>
 #include <qspinbox.h>
@@ -54,7 +55,6 @@
 #include <qtextedit.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qwidgetstack.h>
 #include <qcombobox.h>
 #include <qtabbar.h>
 #include <qlistbox.h>
@@ -68,7 +68,6 @@
 #include <qtextbrowser.h>
 #include <qframe.h>
 #include <qmetaobject.h>
-#include <qwidgetstack.h>
 #include <qwizard.h>
 #include <qvaluelist.h>
 #include <qtimer.h>
@@ -82,7 +81,7 @@
 #endif
 
 #define NO_STATIC_COLORS
-#include <globaldefs.h>
+#include "globaldefs.h"
 
 /* KOMMANDER INCLUDES */
 #include <lineedit.h>
@@ -102,7 +101,7 @@
 #include <tabwidget.h>
 #include <subdialog.h>
 #include <listbox.h>
-
+#include <qwidgetstack.h>
 
 
 FormWindow *find_formwindow( QWidget *w )
@@ -1112,7 +1111,7 @@ QWidget *WidgetFactory::createWidget( const QString &className, QWidget *parent,
 	{
 		QListView *lv = new QListView( parent, name );
 		lv->setSorting( -1 );
-		if ( init ) 
+		if ( init )
 		{
 			lv->addColumn( MainWindow::tr( "Column 1" ) );
 			lv->setCurrentItem( new QListViewItem( lv, MainWindow::tr( "New Item" ) ) );
@@ -1147,7 +1146,7 @@ QWidget *WidgetFactory::createWidget( const QString &className, QWidget *parent,
 	else if(className == "TabWidget")
 	{
 		QTabWidget *tw = new EditorTabWidget( parent, name );
-		if ( init ) 
+		if ( init )
 		{
 			FormWindow *fw = find_formwindow( parent );
 			QWidget *w = fw ? new QDesignerWidget( fw, tw, "tab" ) : new QWidget( tw, "tab" );
@@ -1484,7 +1483,7 @@ void WidgetFactory::editWidget( int id, QWidget *parent, QWidget *editWidget, Fo
     QString className = WidgetDatabase::className( id );
 
 #ifdef KOMMANDER
-    if(className == "ComboBox") 
+    if(className == "ComboBox")
 	{
 		if ( !editWidget->inherits( "QComboBox" ) )
 			return;
@@ -1507,7 +1506,7 @@ void WidgetFactory::editWidget( int id, QWidget *parent, QWidget *editWidget, Fo
 		return;
 	}
 #endif
-    if ( className.mid( 1 ) == "ListBox" ) 
+    if ( className.mid( 1 ) == "ListBox" )
     {
 	if ( !editWidget->inherits( "QListBox" ) )
 	    return;
