@@ -17,9 +17,9 @@ class ExecButton : public QPushButton, public AssocTextWidget
 {
 	Q_OBJECT
 
-	Q_PROPERTY(QStringList associations READ associatedText WRITE setAssociatedText DESIGNABLE false);
-	Q_PROPERTY(bool AssocTextWidget READ isAssociatedTextWidget);
-	Q_PROPERTY(bool writeStdout READ writeStdout WRITE setWriteStdout);
+	Q_PROPERTY(QStringList associations READ associatedText WRITE setAssociatedText DESIGNABLE false)
+	Q_PROPERTY(bool AssocTextWidget READ isAssociatedTextWidget)
+	Q_PROPERTY(bool writeStdout READ writeStdout WRITE setWriteStdout)
 	
 public:
 	ExecButton(QWidget *a_parent, const char *a_name);
