@@ -17,14 +17,16 @@
 #include <list>
 
 //QT includes
+#include <qdir.h>
 #include <qfile.h>
 #include <qfileinfo.h>
 #include <qtextstream.h>
 #include <qregexp.h>
 #include <qradiobutton.h>
+#include <qdatetime.h>
 
 // KDE includes
-#include <kapp.h>
+#include <kapplication.h>
 #include <kwin.h>
 #include <klocale.h>
 #include <kaction.h>
@@ -39,6 +41,8 @@
 #include <ktexteditor/configinterface.h>
 #include <ktexteditor/wordwrapinterface.h>
 
+#include <kdebug.h>
+
 #include "parser/tag.h"
 #include "quantacommon.h"
 #include "document.h"
@@ -46,6 +50,8 @@
 #include "dialogs/dirtydlg.h"
 #include "project/project.h"
 #include "plugins/quantaplugininterface.h"
+#include "qextfileinfo.h"
+#include "quanta.h"
 
 #include <cctype>
 
@@ -100,6 +106,8 @@ Document::Document(const KURL& p_baseURL, KTextEditor::Document *doc,
 
 Document::~Document()
 {
+  delete m_view;
+  delete m_doc;
 }
 
 void Document::resizeEvent(QResizeEvent *e)
@@ -124,7 +132,7 @@ bool Document::isUntitled()
 
 KURL Document::url()
 {
-  return ( isUntitled() ) ? KURL(untitledUrl) : m_doc->url();
+  return ( isUntitled() ) ? KURL("file:/"+untitledUrl) : m_doc->url();
 }
 
 // kwrite addons
@@ -148,6 +156,11 @@ void Document::insertTag(QString s1,QString s2)
     according to dtd. If forwardOnly is true, the text is parsed from (p_line,p_col) forward.*/
 Tag *Document::tagAt(DTDStruct *dtd, int p_line, int p_col, bool forwardOnly, bool useSimpleRx )
 {
+/*
+  QTime t;
+  t.start();
+*/
+
   uint line;
   uint col;
 
@@ -164,7 +177,7 @@ Tag *Document::tagAt(DTDStruct *dtd, int p_line, int p_col, bool forwardOnly, bo
   if (dtd->family == Xml)
   {
     if (!tag) tag = findXMLTag(line, col, forwardOnly, useSimpleRx);
-    if (!tag) tag = findText(line, col, forwardOnly);
+    if (!tag) tag = findText(line, col, forwardOnly, useSimpleRx);
   }
   if (dtd->family == Script)
   {
@@ -188,6 +201,15 @@ Tag *Document::tagAt(DTDStruct *dtd, int p_line, int p_col, bool forwardOnly, bo
       }
     }
   }
+
+/*
+  if (t.elapsed() > 10)
+  {
+    kdDebug(24000) << "DTD: " << dtd->nickName << " line: " << line << " col: " << col << " simple: "<< useSimpleRx << "\n";
+    kdDebug(24000) << "time: " << t.elapsed() <<"ms \n";
+  }
+*/
+
   return tag;
 }
 
@@ -235,7 +257,7 @@ Tag *Document::findScriptText(int line, int col, const QRegExp& keywordRx)
       eLine = el;
       eCol = ec - 1;
     }
-  
+
   if (eCol < 0)
   {
     eLine = (eLine >0)?eLine-1:0;
@@ -305,6 +327,8 @@ Tag *Document::findStruct(int line, int col, const QRegExp& keywordRx)
 
 Tag *Document::findXMLTag(int line, int col, bool forwardOnly, bool useSimpleRx)
 {
+//  kdDebug(24000) << "Document::findXMLTag entered \n";
+
   Tag *tag = 0L;
 //  QRegExp quotedTextRx("(((\\(?=[\"]))\")*[^\"]*)*");
   int bLine, bCol, eLine, eCol;
@@ -318,7 +342,7 @@ Tag *Document::findXMLTag(int line, int col, bool forwardOnly, bool useSimpleRx)
   if (!forwardOnly)
   {
     //search backwards
-    foundText = findRev(xmlTagRx, line, col, bLine, bCol, eLine, eCol);
+    foundText = findRev(xmlTagRx, line, col, bLine, bCol, eLine, eCol, !useSimpleRx);
     if (!foundText.isEmpty())
     {
       if (QuantaCommon::isBetween(line, col, bLine, bCol, eLine, eCol) == 0)
@@ -337,7 +361,7 @@ Tag *Document::findXMLTag(int line, int col, bool forwardOnly, bool useSimpleRx)
   //if not found, search forward
   if (!tagFound)
   {
-   foundText = find(xmlTagRx, sLine, sCol, bLine, bCol, eLine, eCol);
+   foundText = find(xmlTagRx, sLine, sCol, bLine, bCol, eLine, eCol, !useSimpleRx);
    if (!foundText.isEmpty() &&
        QuantaCommon::isBetween(line, col, bLine, bCol, eLine, eCol) == 0)
    {
@@ -357,6 +381,7 @@ Tag *Document::findXMLTag(int line, int col, bool forwardOnly, bool useSimpleRx)
       if (foundText.right(2) == "/>") tag->single = true;
   }
 
+ // kdDebug(24000) << "Document::findXMLTag exited \n";
   return tag;
 }
 
@@ -409,8 +434,11 @@ Tag *Document::findScriptTag(int line, int col,  QRegExp tagRx)
 }
 
 //findXMLTag must be called before
-Tag *Document::findText(int line, int col, bool forwardOnly)
+Tag *Document::findText(int line, int col, bool forwardOnly, bool useSimpleRx)
 {
+
+ // kdDebug(24000) << "Document::findText entered \n";
+
   int bLine = 0;
   int bCol = 0;
   int eLine = 0;
@@ -420,11 +448,12 @@ Tag *Document::findText(int line, int col, bool forwardOnly)
   t_bLine = t_bCol = t_eLine = t_eCol = -1;
   QString foundText;
   QRegExp xmlTagRx("<(?:[^>]*(?:\"(?:[^\"]*(?:<[^\"]*>)+[^\"<]*)*\")*(?:'(?:[^']*(?:<[^']*>)+[^'<]*)*')*[^>]*)*>",false);
+  if (useSimpleRx) xmlTagRx.setPattern("<[^<>]+>");
 
   if (!forwardOnly)
   {
     //search backwards
-    foundText = findRev(xmlTagRx, line, col, bLine, bCol, eLine, eCol);
+    foundText = findRev(xmlTagRx, line, col, bLine, bCol, eLine, eCol, !useSimpleRx);
     if (!foundText.isEmpty())
     {
       t_bCol = eCol+1;
@@ -444,7 +473,7 @@ Tag *Document::findText(int line, int col, bool forwardOnly)
     t_bLine = line;
     t_bCol = col;
   }
-  foundText = find(xmlTagRx, line, col, bLine, bCol, eLine, eCol);
+  foundText = find(xmlTagRx, line, col, bLine, bCol, eLine, eCol, !useSimpleRx);
   if (!foundText.isEmpty())
   {
     t_eCol = bCol-1;
@@ -475,6 +504,8 @@ Tag *Document::findText(int line, int col, bool forwardOnly)
     tag->setWrite(this);
     tag->name = "Text";
   }
+
+ //kdDebug(24000) << "Document::findText exited \n";
  return tag;
 }
 
@@ -503,23 +534,23 @@ void Document::changeTag(Tag *tag, QDict<QString> *dict )
     else
     {
       attrval = QString(" ")+attr+"=";
-      if (! val.startsWith("\\\"")) attrval += "\"";
+      if (!val.startsWith("\\\"") && !val.startsWith("\\\'")) attrval += qConfig.attrValueQuotation;
       attrval += val;
-      if (! val.endsWith("\\\"")) attrval += "\"";
+      if (!val.endsWith("\\\"") && !val.endsWith("\\\'")) attrval += qConfig.attrValueQuotation;
     }
     tagStr = attrval + tagStr;
     ++it;
   }
   tagStr = "<"+QuantaCommon::tagCase(tag->name)+tagStr;
 
-  if ( qTag && qTag->parentDTD->singleTagStyle == "xml" &&
+  if ( dict && !dict->isEmpty() && qTag && qTag->parentDTD->singleTagStyle == "xml" &&
        (qTag->isSingle() || (!qConfig.closeOptionalTags && qTag->isOptional()))
      )
   {
     tagStr.append(" /");
   }
   tagStr.append(">");
-  
+
   int bLine, bCol, eLine, eCol;
   tag->beginPos(bLine,bCol);
   tag->endPos(eLine,eCol);
@@ -543,7 +574,7 @@ void Document::insertAttrib(QString attr)
   {
     tag->endPos(line, col);
     viewCursorIf->setCursorPositionReal( line, col - 1 );
-    insertTag( QString(" ") + QuantaCommon::attrCase(attr) + "=\"", QString( "\"" ) );
+    insertTag( " " + QuantaCommon::attrCase(attr) + "="+qConfig.attrValueQuotation, qConfig.attrValueQuotation );
     delete tag;
   }
 }
@@ -570,20 +601,11 @@ void Document::readConfig(KConfig *config)
   bool m = m_doc->isModified();
   dynamic_cast<KTextEditor::ConfigInterface*>(m_doc)->readConfig( config );
   m_doc->setModified(m);
-  //read the line number & icon border setting from the General section
-//  config->setGroup("General Options");
-//  qConfig.lineNumbers = config->readBoolEntry("LineNumbers", false);
-//  qConfig.iconBar = config->readBoolEntry("Iconbar", false);
 }
 
 void Document::writeConfig(KConfig *config)
 {
   dynamic_cast<KTextEditor::ConfigInterface*>(m_doc)->writeConfig( config );
-  //store the line number & icon border setting also in the General section
-  config->setGroup("Kate View");
-  config->writeEntry("LineNumbers", qConfig.lineNumbers);
-  config->writeEntry("Iconbar", qConfig.iconBar);
-  config->writeEntry("DynamicWordWrap", qConfig.dynamicWordWrap);
 }
 
 /** No descriptions */
@@ -651,7 +673,7 @@ void Document::insertText(QString text, bool adjustCursor)
         }
         if(wordLength == -1)
           wordLength = (textLength)-i;
-          
+
         if((wordLength+col) > wordWrapAt)
         {
           if(col && !lineLock) // wraps onto new line unless locked by kate
@@ -696,10 +718,10 @@ KTextEditor::Document* Document::doc()
 bool Document::isModified()
 {
   bool modified = false;
-  if ( m_doc )	
+  if ( m_doc )
    modified = m_doc->isModified();
 
-  return modified;	
+  return modified;
 }
 /** Sets the modifiedFlag value. */
 void Document::setModified(bool flag)
@@ -788,7 +810,7 @@ QString Document::getTagNameAt(DTDStruct *dtd, int line, int col )
      QString s = tag->tagStr();
      int pos = s.find("<");
      if (pos !=-1)
-     {   
+     {
        s.remove(0,pos);
        pos = 0;
        while (pos < (int)s.length() && !s[pos].isSpace()) pos++;
@@ -831,15 +853,15 @@ void Document::slotCompletionDone( KTextEditor::CompletionEntry completion )
   }
   if (completion.type == "attributeValue")
   {
-    viewCursorIf->setCursorPositionReal(line,col+1);
+    viewCursorIf->setCursorPositionReal(line, col);
   }
   if (completion.type == "doctypeList")
   {
-    viewCursorIf->setCursorPositionReal(line,col+1);
+    viewCursorIf->setCursorPositionReal(line, col+1);
   }
   if (completion.type == "function")
   {
-    viewCursorIf->setCursorPositionReal(line,col+1);
+    viewCursorIf->setCursorPositionReal(line, col);
     if (dtd) scriptAutoCompletion(dtd,line,col-1,"(");
   }
 }
@@ -857,7 +879,7 @@ void Document::slotFilterCompletion( KTextEditor::CompletionEntry *completion ,Q
 
   if ( completion->type == "attribute" )
   {
-    string->append("=\"\"");
+    string->append("="+QString(qConfig.attrValueQuotation)+QString(qConfig.attrValueQuotation));
   }
   if (completion->type == "doctypeList")
   {
@@ -900,16 +922,16 @@ void Document::slotCharactersInserted(int line,int column,const QString& string)
       handled = scriptAutoCompletion(dtd, line, column, string);
     }
 
-    if (!handled)
+    DTDStruct *default_dtd = defaultDTD();
+    if (!handled && dtd != default_dtd)
     {
-      dtd = defaultDTD();
-      if (dtd->family == Xml)
+      if (default_dtd->family == Xml)
       {
-        xmlAutoCompletion(dtd, line, column, string);
+        xmlAutoCompletion(default_dtd, line, column, string);
       }
-      if (dtd->family == Script)
+      if (default_dtd->family == Script)
       {
-        scriptAutoCompletion(dtd, line, column, string);
+        scriptAutoCompletion(default_dtd, line, column, string);
       }
     }
   }
@@ -969,7 +991,7 @@ bool Document::xmlAutoCompletion(DTDStruct* dtd, int line, int column, const QSt
           //suggest attribute completions
           showCodeCompletions( getAttributeCompletions(dtd, tagName) );
          }
-         else if ( string == "\"" )
+         else if ( string[0] == qConfig.attrValueQuotation )
               {
                //we need to find the attribute name
                QString textLine = editIf->textLine(line).left(column-1);
@@ -1051,11 +1073,11 @@ QValueList<KTextEditor::CompletionEntry>* Document::getAttributeCompletions( DTD
   KTextEditor::CompletionEntry completion;
   QTag *tag = QuantaCommon::tagFromDTD(dtd, tagName);
   startsWith = startsWith.upper();
-  switch (dtd->family)
+  if (tag)
   {
-     case Xml:
-          {
-            if (tag)
+    switch (dtd->family)
+    {
+      case Xml:
             {
               completion.type = "attribute";
               completion.userdata = startsWith+"|"+tag->name();
@@ -1078,28 +1100,28 @@ QValueList<KTextEditor::CompletionEntry>* Document::getAttributeCompletions( DTD
                 QDictIterator<DTDStruct> it(*dtds);
                 for( ; it.current(); ++it )
                 {
-                 completion.type = "doctypeList";
-                 completion.text = it.current()->nickName;
-                 completions->append(completion);
+                completion.type = "doctypeList";
+                completion.text = it.current()->nickName;
+                completions->append(completion);
                 }
               }
-            } // if (tag)
-            break;
-          }
-     case Script:
-          {
-            completion.userdata = startsWith+"|"+tag->name();
-            completion.type = "script";
-            AttributeList *list = tag->attributes();
-            for (uint i = 0; i < list->count(); i++)
-            {
-              QString item = list->at(i)->name;
-              completion.text = item;
-              completion.comment = list->at(i)->type;
-              completions->append( completion );
+              break;
             }
-          }
-    }
+      case Script:
+            {
+              completion.userdata = startsWith+"|"+tag->name();
+              completion.type = "script";
+              AttributeList *list = tag->attributes();
+              for (uint i = 0; i < list->count(); i++)
+              {
+                QString item = list->at(i)->name;
+                completion.text = item;
+                completion.comment = list->at(i)->type;
+                completions->append( completion );
+              }
+            }
+      }
+    } // if (tag)
 
 //  completionInProgress = true;
   return completions;
@@ -1114,7 +1136,7 @@ QValueList<KTextEditor::CompletionEntry>* Document::getAttributeValueCompletions
   completion.type = "attributeValue";
   completion.userdata = startsWith+"|"+tagName + "," + attribute;
 
-  QStringList *values = QuantaCommon::tagAttributeValues(dtd->name,tagName,attribute);
+  QStringList *values = tagAttributeValues(dtd->name,tagName,attribute);
   if (values)
   {
     for ( QStringList::Iterator it = values->begin(); it != values->end(); ++it )
@@ -1126,7 +1148,7 @@ QValueList<KTextEditor::CompletionEntry>* Document::getAttributeValueCompletions
       }
     }
   }
-  
+
 //  completionInProgress = true;
   return completions;
 }
@@ -1260,9 +1282,9 @@ bool Document::scriptAutoCompletion(DTDStruct *dtd, int line, int column, const
  if (string == "$")
  {
    showCodeCompletions( getVariableCompletions(dtd, line, column) );
-   handled = true; 
+   handled = true;
  }
- 
+
  return handled;
 }
 
@@ -1292,32 +1314,40 @@ QString Document::text(int bLine, int bCol, int eLine, int eCol)
  return t;
 }
 
-QString Document::find(const QRegExp& regExp, int sLine, int sCol, int& fbLine, int&fbCol, int &feLine, int&feCol)
+QString Document::find(const QRegExp& regExp, int sLine, int sCol, int& fbLine, int&fbCol, int &feLine, int&feCol, bool incremental)
 {
 
  QRegExp rx = regExp;
  QString foundText = "";
  int maxLine = editIf->numLines();
- QString textToSearch = text(sLine, sCol, sLine, editIf->lineLength(sLine));
  int pos;
- int line = sLine;  
- do
+ QString textToSearch;
+
+ if (incremental)
  {
-   pos = rx.search(textToSearch);
-   if (pos == -1)
+   int line = sLine;
+   textToSearch = text(sLine, sCol, sLine, editIf->lineLength(sLine));
+   do
    {
-/*     if (line + STEP < maxLine)
+     pos = rx.search(textToSearch);
+     if (pos == -1)
      {
-       line += STEP;
-       textToSearch.append("\n"+text(line - STEP + 1, 0, line, editIf->lineLength(line)));
-     } else*/
-     {
-      line ++;
-      if (line < maxLine) textToSearch.append("\n"+editIf->textLine(line));
+  //     if (line + STEP < maxLine)
+  //     {
+  //       line += STEP;
+  //       textToSearch.append("\n"+text(line - STEP + 1, 0, line, editIf->lineLength(line)));
+  //     } else
+       {
+        line ++;
+        if (line < maxLine) textToSearch.append("\n"+editIf->textLine(line));
+       }
      }
-   }
- } while (line < maxLine && pos == -1);
-// pos = rx.search(text(sLine, sCol, maxLine -1, 100));
+   } while (line < maxLine && pos == -1);
+ } else
+ {
+   textToSearch = text(sLine, sCol, maxLine -1, editIf->lineLength(maxLine-1));
+ }
+ pos = rx.search(textToSearch);
  if (pos != -1)
  {
    foundText = rx.cap();
@@ -1338,47 +1368,67 @@ QString Document::find(const QRegExp& regExp, int sLine, int sCol, int& fbLine,
    }
    if (fbCol < 0) fbCol = 0;
    if (feCol < 0) feCol = 0;
-/*
+
    s = text(fbLine, fbCol, feLine, feCol);
    if (s != foundText) //debug, error
    {
      KMessageBox::error(this,"Found: "+foundText+"\nRead: "+s);
    }
-*/
+
  }
 
  return foundText;
 }
 
-QString Document::findRev(const QRegExp& regExp, int sLine, int sCol, int& fbLine, int&fbCol, int &feLine, int&feCol)
+QString Document::findRev(const QRegExp& regExp, int sLine, int sCol, int& fbLine, int&fbCol, int &feLine, int&feCol, bool incremental)
 {
  QRegExp rx = regExp;
  QString foundText = "";
  int pos = -1;
  int line = sLine;
- QString textToSearch = text(sLine, 0, sLine, sCol);
- do
+ QString textToSearch;
+
+ if (incremental)
  {
-   pos = rx.searchRev(textToSearch);
-   if (pos == -1)
+   textToSearch = text(sLine, 0, sLine, sCol);
+   do
    {
-/*     if (line - STEP >= 0)
+     pos = rx.searchRev(textToSearch);
+     if (pos == -1)
      {
-         textToSearch.prepend(text(line - STEP, 0, line - 1, editIf->lineLength(line-1)) + "\n");
-         line -= STEP;
-     } else */
-     {
-       line--;
-       if (line >=0) textToSearch.prepend(editIf->textLine(line) + "\n");
+  //     if (line - STEP >= 0)
+  //     {
+  //         textToSearch.prepend(text(line - STEP, 0, line - 1, editIf->lineLength(line-1)) + "\n");
+  //         line -= STEP;
+  //     } else
+       {
+         line--;
+         if (line >=0) textToSearch.prepend(editIf->textLine(line) + "\n");
+       }
      }
-   }
- } while (line >=0 && pos == -1);
+   } while (line >=0 && pos == -1);
+ } else
+ {
+   textToSearch = text(0, 0, sLine, sCol);
+ }
+ pos = rx.searchRev(textToSearch);
  if (pos != -1)
  {
    foundText = rx.cap();
+
+   int linesInFound = foundText.contains("\n");
+
+   if (incremental)
+   {
    fbLine = line;
    fbCol = pos;
-   int linesInFound = foundText.contains("\n");
+   } else
+   {
+    QString leftStr = textToSearch.left(pos);
+    fbLine = leftStr.contains('\n');
+    fbCol = pos - leftStr.findRev('\n') - 1;
+   }
+
    feCol = foundText.length()-foundText.findRev("\n")-2;
    feLine = fbLine + linesInFound;
    if (linesInFound == 0)
@@ -1387,8 +1437,8 @@ QString Document::findRev(const QRegExp& regExp, int sLine, int sCol, int& fbLin
    }
    if (fbCol < 0) fbCol = 0;
    if (feCol < 0) feCol = 0;
-/*
-   QString s = text(fbLine, fbCol, feLine, feCol);
+
+/*   QString s = text(fbLine, fbCol, feLine, feCol);
    if (s != foundText) //debug, error
    {
      KMessageBox::error(this,"FindRev\nFound: "+foundText+"\nRead: "+s);
@@ -1426,7 +1476,7 @@ void Document::codeCompletionRequested()
     if (dtd->family == Script)
     {
       scriptCodeCompletion(dtd, line, col);
-    }             
+    }
   }
   completionInProgress = true;
 }
@@ -1540,7 +1590,7 @@ bool Document::scriptCodeCompletion(DTDStruct *dtd, int line, int col)
        scriptAutoCompletion(dtd, line, col, "$");
        goAhead = false;
        handled = true;
-     }  
+     }
    }
 
    if (goAhead)
@@ -1577,21 +1627,42 @@ void Document::checkDirtyStatus()
   fileWatcher->stopScan();
   if (m_dirty)
   {
-    createTempFile();
-    DirtyDlg *dlg = new DirtyDlg(url().path(), m_tempFileName, this);
-    if (!m_pluginInterface || !(m_pluginInterface->pluginAvailable("kompare")))
+    if (url().isLocalFile())
     {
-       dlg->buttonCompare->setEnabled(false);
-       dlg->buttonLoad->setChecked(true);
+      //check if the file is changed, also by file content. Might help to reduce
+      //unwanted warning on NFS
+      QFile f(url().path());
+      if (f.open(IO_ReadOnly))
+      {
+        QString content;
+        QTextStream stream(&f);
+        content = stream.read();
+        if (content == editIf->text())
+        {
+          m_dirty = false;
+        }
+        f.close();
+      }
+
     }
-    if (dlg->exec())
+    if (m_dirty)
     {
-        m_doc->setModified(false);
-        m_doc->openURL(url());
-        createTempFile();
+     createTempFile();
+     DirtyDlg *dlg = new DirtyDlg(url().path(), m_tempFileName, this);
+     if (!m_pluginInterface || !(m_pluginInterface->pluginAvailable("kompare")))
+     {
+        dlg->buttonCompare->setEnabled(false);
+        dlg->buttonLoad->setChecked(true);
+     }
+     if (dlg->exec())
+     {
+         m_doc->setModified(false);
+         m_doc->openURL(url());
+         createTempFile();
+     }
+     delete dlg;
     }
     m_dirty = false;
-    delete dlg;
   }
   fileWatcher->startScan();
 }
@@ -1685,4 +1756,55 @@ void Document::slotTextChanged()
  parser->parseForDTD(this, force);
 }
 
+/** Returns list of values for attribute */
+QStringList* Document::tagAttributeValues(const QString& dtdName, const QString& tag, const QString &attribute)
+{
+  QStringList *values = 0L;
+
+  DTDStruct* dtd = dtds->find(dtdName.lower());
+  if (dtd)
+  {
+    QString searchForAttr = (dtd->caseSensitive) ? attribute : attribute.upper();
+    AttributeList* attrs = QuantaCommon::tagAttributes(dtdName, tag);
+    Attribute *attr;
+    KURL u;
+    KURL base = QExtFileInfo::toRelative(url(), baseURL);
+    base.setPath("/"+base.directory(false, false));
+    QString s;
+    if (attrs)
+    {
+      for ( attr = attrs->first(); attr; attr = attrs->next() )
+      {
+        QString attrName = (dtd->caseSensitive) ? attr->name : attr->name.upper();        if (attrName == searchForAttr)
+        {
+          if (attr->type == "url") {
+            Project *project = quantaApp->getProject();
+            if (project->hasProject())
+            {
+              values = new QStringList(project->fileNameList(true).toStringList());
+              for (uint i = 0; i < values->count(); i++)
+              {
+                u = (*values)[i];
+                u.setPath("/"+u.path());
+                u = QExtFileInfo::toRelative(u, base);
+                (*values)[i] = u.path();
+              }
+              values->append("mailto:" + project->email);
+            } else
+            {
+              QDir dir = QDir(url().directory());
+              values = new QStringList(dir.entryList());
+            }
+            break;
+          } else {
+            values = &attr->values;
+            break;
+          }
+        }
+      }
+    }
+  }
+  return values;
+}
+
 #include "document.moc"
