@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Mar 16 2000
     copyright            : (C) 2000 by Yacovlev Alexander & Dmitry Poplavsky
-    							         (C) 2001, 2002 by Andras Mantia
+    							         (C) 2001-2003 by Andras Mantia
     email                : pdima@mail.univ.kiev.ua, amantia@freemail.hu
  ***************************************************************************/
 
@@ -51,7 +51,7 @@
 #include <kaction.h>
 #include <ktempfile.h>
 #include <kstdaction.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kfiledialog.h>
 #include <klineeditdlg.h>
 #include <kmessagebox.h>
@@ -80,7 +80,7 @@ Project::Project( QWidget *, const char *name )
         : QWidget(0L,name)
 {
   projectName = QString::null;
-  config = 0L;     
+  config = 0L;
   modified=false;
   olfwprj=false;
   usePreviewPrefix=false;
@@ -104,9 +104,9 @@ KURL::List Project::fileNameList(bool check)
 {
 	KURL::List list;
 
-  //cout << dom.toString() << "\n";  
+  //cout << dom.toString() << "\n";
 	QDomNodeList nl = dom.elementsByTagName("item");
-	
+
 	for ( unsigned int i=0; i < nl.count(); i++ )
   {
 		QDomElement el = nl.item(i).cloneNode().toElement();
@@ -148,7 +148,7 @@ void Project::insertFile(const KURL& nameURL, bool repaint )
 
 	QDomElement  el;
 	QDomNodeList nl = dom.elementsByTagName("item");
-	
+
 	for ( uint i = 0; i < nl.count(); i++ )
   {
 		el = nl.item(i).toElement();
@@ -191,7 +191,7 @@ void Project::insertFiles( KURL::List files )
 
   QDomElement  el;
   QDomNodeList nl = dom.elementsByTagName("item");
-	
+
   for ( uint i = 0; i < nl.count(); i++ )
   {
 		el = nl.item(i).toElement();
@@ -297,7 +297,7 @@ void Project::writeConfig(KConfig *config)
   config->writeEntry("Last Project", projectURL.url());
   config->deleteGroup("RecentProjects");
   projectRecent->saveEntries(config, "RecentProjects");
-  
+
 //  slotSaveProject();
 }
 
@@ -363,7 +363,7 @@ bool Project::slotSaveProject()
         i--;
       }
     }
-  
+
     KTempFile *tmpFile = new KTempFile(tmpDir);
     tmpFile->setAutoDelete(true);
     dom.save(*(tmpFile->textStream()), 0);
@@ -411,7 +411,9 @@ void Project::slotCloseProject()
 
   projectURL  = KURL();
   modified = false;
-  passwd = "";  
+  passwd = "";
+  usePreviewPrefix = false;
+  previewPrefix = KURL();
 
   emit newStatus();
 }
@@ -423,7 +425,7 @@ void Project::slotLoadProject(const KURL &a_url)
   projectURL = KURL();
   projectName = QString::null;
   currentProjectView = QString::null;
-  
+
   if (url.isMalformed())
   {
       KMessageBox::sorry(this, i18n("Malformed URL\n%1").arg(url.prettyURL()));
@@ -462,13 +464,13 @@ void Project::loadProjectXML()
   KURL url;
   QDomNode projectNode = dom.firstChild().firstChild();
   projectName = projectNode.toElement().attribute("name");
-	
+
   if ( projectNode.isNull() || projectName.isEmpty() )
   {
     KMessageBox::sorry( this, i18n("Invalid project file.") );
     return;
   }
-	
+
   modified = false;
   QString tmpString = projectNode.toElement().attribute("previewPrefix");
   if ( !tmpString.isEmpty())
@@ -505,7 +507,7 @@ void Project::loadProjectXML()
 
   no = projectNode.namedItem("autoload");
   currentProjectView = no.toElement().attribute("projectview");
-            
+
   no = projectNode.namedItem("templates");
   tmpString = no.firstChild().nodeValue();
   templateURL = baseURL;
@@ -515,7 +517,7 @@ void Project::loadProjectXML()
     modified = true;
   }
   else
-  { 
+  {
     QuantaCommon::setUrl(templateURL, tmpString);
   }
   if (tmpString != QuantaCommon::qUrl(templateURL) )
@@ -614,9 +616,9 @@ void Project::loadProjectXML()
   emit reloadTree( fileList, true);
 
   emit showTree();
-  emit newStatus();                  
-  
-  passwd = "";   
+  emit newStatus();
+
+  passwd = "";
 }
 
 // slot for insert file
@@ -630,12 +632,12 @@ void Project::slotAddFiles()
 {
 	KURL::List list = KFileDialog::getOpenURLs(
 		baseURL.url(),	i18n("*"), this, i18n("Insert Files in Project"));
-		
+
 	if ( !list.isEmpty() )
   {
   	KURL firstURL = list.first();
   	firstURL = QExtFileInfo::toRelative( firstURL, baseURL );
-  	
+
   	if ( firstURL.path().startsWith("/") || firstURL.path().startsWith("."))
   	{
   		CopyTo *dlg = new CopyTo( baseURL, this, i18n("Files: copy to project...") );
@@ -652,7 +654,7 @@ void Project::slotAddFiles()
         return;
       }
   	}
-  	
+
    insertFiles( list );
    //Take care also of the selected dirs
    KURL dirURL;
@@ -660,11 +662,11 @@ void Project::slotAddFiles()
    {
      dirURL = list[i];
      if (dirURL.path().endsWith("/"))
-     {     
+     {
        insertFiles( dirURL, "*" );
      }
    }
-  	
+
   	emit reloadTree( fileNameList(), false);
   }
 }
@@ -675,7 +677,7 @@ void Project::slotAddDirectory()
  #if KDE_VERSION < 308
 	 QString dir = KFileDialog::getExistingDirectory(baseURL.prettyURL(), this,
                 i18n("Insert Directory in Project"));
-   url = baseURL;             
+   url = baseURL;
    QuantaCommon::setUrl(url,dir);
  #else
    url = KFileDialog::getExistingURL(baseURL.prettyURL(), this,
@@ -689,7 +691,7 @@ void Project::slotAddDirectory(const KURL& p_dirURL, bool showDlg)
   KURL dirURL = p_dirURL;
 	if ( hasProject() && !dirURL.isEmpty() )
   {
-	
+
     dirURL.adjustPath(1);
   	KURL relURL = QExtFileInfo::toRelative(dirURL, baseURL);
 
@@ -725,7 +727,7 @@ void Project::slotInsertFilesAfterCopying(const KURL& p_url,CopyTo* dlg)
 {
   KURL url = p_url;
 //The CopyTo dlg is deleted only here!!
-  delete dlg;	
+  delete dlg;
   url.adjustPath(1);
   insertFiles( url, "*" );
   emit reloadTree( fileNameList(), false );
@@ -749,13 +751,26 @@ void Project::slotRenameFinished( KIO::Job * job)
     for (uint i = 0; i < nl.count(); i++ )
     {
       el = nl.item(i).toElement();
-      tmpString = el.attribute("url");    
-      oldString = tmpString;
-      tmpString = tmpString.replace(QRegExp(oldStr),newStr);
-      if (oldString != tmpString )
+      tmpString = el.attribute("url");
+      if (tmpString == newStr)
       {
-        el.setAttribute("url",tmpString);
-        el.setAttribute("upload_time","");
+        el.parentNode().removeChild( el );
+        break;
+      }
+    }
+    for (uint i = 0; i < nl.count(); i++ )
+    {
+      el = nl.item(i).toElement();
+      tmpString = el.attribute("url");
+      if (tmpString.startsWith(oldStr))
+      {
+        oldString = tmpString;
+        tmpString = tmpString.replace(QRegExp(oldStr),newStr);
+        if (oldString != tmpString )
+        {
+          el.setAttribute("url",tmpString);
+          el.setAttribute("upload_time","");
+        }
       }
     }
     oldURL = KURL();
@@ -763,6 +778,7 @@ void Project::slotRenameFinished( KIO::Job * job)
     modified = true;
 
     emit reloadTree( fileNameList(), false );
+    emit newStatus();
   }
 }
 
@@ -782,7 +798,7 @@ void Project::slotRename(const KURL& url)
     oldName = url.fileName();
     caption = i18n("Rename File");
   }
-                                      
+
   KLineEditDlg dlg(i18n("Enter the new name:"), oldName, this);
   dlg.setCaption(caption);
 
@@ -803,10 +819,18 @@ void Project::slotRename(const KURL& url)
       //set the class global attributes
       oldURL = QExtFileInfo::toRelative(url, baseURL);
       newURL = QExtFileInfo::toRelative(newUrl, baseURL);
-      //start the rename job
 
-      KIO::SimpleJob *job = KIO::rename( url, newUrl, true );
-      connect( job, SIGNAL( result( KIO::Job *) ), SLOT( slotRenameFinished( KIO::Job *) ));
+      bool proceed = true;
+      if (QExtFileInfo::exists(newUrl))
+      {
+        proceed = KMessageBox::questionYesNo(this, i18n("A file with the same name already exists.\nDo you want to overwrite it?"),i18n("Overwrite")) == KMessageBox::Yes;
+      }
+      if (proceed)
+      {
+       //start the rename job
+        KIO::SimpleJob *job = KIO::rename( url, newUrl, true );
+        connect( job, SIGNAL( result( KIO::Job *) ), SLOT( slotRenameFinished( KIO::Job *) ));
+      }	
     }
   }
 }
@@ -823,7 +847,7 @@ void Project::slotRemove(const KURL& urlToRemove)
   for ( uint i = 0; i < nl.count(); i++ )
   {
     el = nl.item(i).toElement();
-    
+
     tmpString = el.attribute("url");
     if ( ( !isFolder && tmpString == urlStr) ||
          ( isFolder && tmpString.startsWith(urlStr))
@@ -848,8 +872,6 @@ void Project::slotNewProject()
 {
 	wiz = new QWizard( 0, "new", true);
 	wiz->setMinimumSize(620,440);
-	wiz->setMaximumSize(620,440);
-	wiz->setSizePolicy(QSizePolicy(QSizePolicy::Fixed,QSizePolicy::Fixed));
 
 	png = new ProjectNewGeneral( wiz );
 
@@ -925,8 +947,8 @@ void Project::slotNewProject()
        break;
      }
   }
-  
-  png->linePrjName->setFocus();         
+
+  png->linePrjName->setFocus();
 	if ( wiz->exec() ) slotAcceptCreateProject();
 
 	delete wiz;
@@ -946,7 +968,7 @@ void Project::slotAcceptCreateProject()
 {
   slotCloseProject();
   bool errorOccured = false;
-  
+
   projectName = png->linePrjName->text();
   QString basePath = png->linePrjDir ->text();
 
@@ -964,7 +986,7 @@ void Project::slotAcceptCreateProject()
   if (!QExtFileInfo::createDir( baseURL ))
   {
     QuantaCommon::dirCreationError(this, baseURL);
-    baseURL = oldBaseURL;                     
+    baseURL = oldBaseURL;
   } else
   {
     projectURL = baseURL;
@@ -978,7 +1000,7 @@ void Project::slotAcceptCreateProject()
       m_defaultDTD = QuantaCommon::getDTDNameFromNickName(pnf->dtdCombo->currentText());
       m_defaultEncoding  = pnf->encodingCombo->currentText();
       m_newFileType  = QuantaCommon::getDTDNameFromNickName(pnf->newfileCombo->currentText());
-      
+
       QuantaCommon::setUrl(previewPrefix, pnf->linePrefix->text());
       previewPrefix.adjustPath(1);
 
@@ -1109,7 +1131,7 @@ void Project::slotOptions()
 
   optionsPage->lineAuthor->setText( author );
 	optionsPage->lineEmail->setText( email );
-	
+
 	optionsPage->linePrefix->setText(previewPrefix.url());
   QString name;
   int index;
@@ -1141,7 +1163,7 @@ void Project::slotOptions()
        break;
      }
   }
-  
+
 
   QStringList list;
   QDomNodeList nl = dom.elementsByTagName("projectview");
@@ -1196,7 +1218,7 @@ void Project::slotOptions()
     {
       QuantaCommon::dirCreationError(this, toolbarURL);
     }
-		
+
 		QuantaCommon::setUrl(previewPrefix,optionsPage->linePrefix->text()+"/");
     previewPrefix.adjustPath(1);
 		usePreviewPrefix = optionsPage->checkPrefix->isChecked();
@@ -1210,27 +1232,19 @@ void Project::slotOptions()
     el.setAttribute("encoding", m_defaultEncoding);
     el.setAttribute("newfiles", m_newFileType);
 
- 		el = dom.firstChild().firstChild().namedItem("author").toElement();
- 		if (el.isNull())
- 		{
- 		  el = dom.createElement("author");
-		  dom.firstChild().firstChild().appendChild( el );
-          el.appendChild( dom.createTextNode( author ) );
- 		} else
- 		{
- 		  el.firstChild().setNodeValue(author);
- 		}
+    el = dom.firstChild().firstChild().namedItem("author").toElement();
+    if (!el.isNull())
+       el.parentNode().removeChild(el);
+    el = dom.createElement("author");
+    dom.firstChild().firstChild().appendChild( el );
+    el.appendChild( dom.createTextNode( author ) );
 
- 		el = dom.firstChild().firstChild().namedItem("email").toElement();
- 		if (el.isNull())
- 		{
- 		  el = dom.createElement("email");
-		  dom.firstChild().firstChild().appendChild( el );
-          el.appendChild( dom.createTextNode( email ) );
- 		} else
- 		{
- 		  el.firstChild().setNodeValue(email);
- 		}
+    el = dom.firstChild().firstChild().namedItem("email").toElement();
+    if (!el.isNull())
+       el.parentNode().removeChild(el);
+    el = dom.createElement("email");
+    dom.firstChild().firstChild().appendChild( el );
+    el.appendChild( dom.createTextNode( email ) );
 
     el = dom.firstChild().firstChild().namedItem("defaultDTD").toElement();
     if(el.isNull())
@@ -1248,7 +1262,7 @@ void Project::slotOptions()
     url = QExtFileInfo::toRelative(templateURL, baseURL);
     if(el.isNull())
     {
-      el = dom.createElement("templates");     
+      el = dom.createElement("templates");
       dom.firstChild().firstChild().appendChild(el);
       el.appendChild(dom.createTextNode(QuantaCommon::qUrl(url)));
     }
@@ -1285,7 +1299,7 @@ void Project::slotOptions()
    		}
     }
     modified = true;
-		
+
 		emit setProjectName( projectName );
     emit templateURLChanged( templateURL );
 		emit newStatus();
@@ -1307,7 +1321,7 @@ void Project::slotUploadURL(const KURL& urlToUpload)
   emit saveAllFiles();
   KURL url = QExtFileInfo::toRelative( urlToUpload, baseURL);
 
-  ProjectUpload *dlg = new ProjectUpload(this, url, 0, i18n("Upload project items..."), false, Qt::WDestructiveClose); 
+  ProjectUpload *dlg = new ProjectUpload(this, url, 0, i18n("Upload project items..."), false, Qt::WDestructiveClose);
   dlg->show();
 }
 
@@ -1398,7 +1412,7 @@ void Project::openCurrentView()
         break;
       }
    }
- }  
+ }
 }
 
 /** Opens a project view (toolbars & files). */
@@ -1458,7 +1472,7 @@ void Project::slotSaveAsProjectView(bool askForName)
         }
       }
     }
-    
+
     KURL::List fileList = fileNameList();
     QDomElement el = dom.createElement("projectview");
     el.setAttribute("name", currentProjectView);
@@ -1481,10 +1495,12 @@ void Project::slotSaveAsProjectView(bool askForName)
     for (uint i =0 ; i < toolbarList.count(); i++)
     {
       item = dom.createElement("viewtoolbar");
-      item.setAttribute("url", QuantaCommon::qUrl(toolbarList[i]) );
+      KURL url = toolbarList[i];
+      url = QExtFileInfo::toRelative(url, baseURL);
+      item.setAttribute("url", QuantaCommon::qUrl(url) );
       el.appendChild(item);
     }
-    
+
     dom.firstChild().firstChild().appendChild( el );
     slotSaveProject();
   }
@@ -1497,5 +1513,11 @@ void Project::slotSaveProjectView()
   slotSaveAsProjectView(currentProjectView.isEmpty());
 }
 
+void Project::setModified(bool b)
+{
+  modified = b;
+  emit newStatus();
+}
+
 
 #include "project.moc"
