@@ -87,7 +87,7 @@ KURL::List QuantaDoc::openedFiles(bool noUntitled)
   if (quantaApp->getView()) //need to check otherwise it may crash on exit
   {
     QTabWidget *tab = quantaApp->getView()->writeTab;
-    for (int i = 0; i < tab->count(); i++) 
+    for (int i = 0; i < tab->count(); i++)
     {
       Document *w = dynamic_cast<Document *>(tab->page(i));
       if ( !w->isUntitled() || !noUntitled )
@@ -121,7 +121,7 @@ bool QuantaDoc::newDocument( const KURL& url )
 
     if ( newfile ) furl = w->url().url();
 
-  	quantaApp ->view->addWrite( w, w->url().url() );
+    quantaApp ->view->addWrite( w, w->url().url() );
 
     quantaApp->processDTD(quantaApp->getProject()->defaultDTD());
 
@@ -140,14 +140,22 @@ bool QuantaDoc::newDocument( const KURL& url )
     w = isOpened(furl);
     w->checkDirtyStatus();
     quantaApp ->view->writeTab->showPage( w );
-  	return false; // don't need loadURL
+    return false; // don't need loadURL
   }
 
   return true;
 }
 
-void QuantaDoc::openDocument(const KURL& url, QString encoding)
+void QuantaDoc::openDocument(const KURL& urlToOpen, QString encoding)
 {
+  KURL url = urlToOpen;
+  if (url.isLocalFile())
+  {
+    QString path = QDir(url.path()).canonicalPath();
+    if (!path.isEmpty())
+        url.setPath(path);
+  }
+
 //  Document *ww = write();
   //kdDebug() << k_funcinfo << "Encoding is: " << encoding << endl;
   if ( !newDocument( url )) return;
@@ -200,19 +208,20 @@ void QuantaDoc::openDocument(const KURL& url, QString encoding)
 
       write()->createTempFile();
       emit title( write()->url().prettyURL() );
-      write()->view()->setFocus();     
-    } 
+      write()->view()->setFocus();
+    }
   }
  if (!loaded && !url.isEmpty()) //the open of the document has failed
  {
    KMessageBox::error(quantaApp, i18n("Cannot open document \"%1\".").arg(url.prettyURL()));
    closeDocument();
  }
- 
+
 }
 
-void QuantaDoc::saveDocument(const KURL& url)
+bool QuantaDoc::saveDocument(const KURL& url)
 {
+  bool result = true;
   Document *w = write();
   KURL oldURL = w->url();
 
@@ -222,6 +231,7 @@ void QuantaDoc::saveDocument(const KURL& url)
     if (!w->doc()->saveAs( url ))
     {
       KMessageBox::error(quantaApp, i18n("Saving of the document\n%1\nfailed.\nMaybe you should try to save in another directory.").arg(url.prettyURL()));
+      result = false;
     }
     w->closeTempFile();
     w->createTempFile();
@@ -230,6 +240,9 @@ void QuantaDoc::saveDocument(const KURL& url)
     {
       fileWatcher->addFile(w->url().path());
     }
+  } else
+  {
+    result = false;
   }
 
   // fix
@@ -240,7 +253,7 @@ void QuantaDoc::saveDocument(const KURL& url)
 
   emit title( w->url().url() );
 
-  return;
+  return result;
 }
 
 bool QuantaDoc::saveAll(bool dont_ask)
@@ -251,23 +264,24 @@ bool QuantaDoc::saveAll(bool dont_ask)
 
   QTabWidget *docTab =quantaApp->getView()->writeTab;
   Document *w;
-  for (int i = docTab->count() -1; i >=0; i--) 
+  for (int i = docTab->count() -1; i >=0; i--)
   {
     w = dynamic_cast<Document*>(docTab->page(i));
     if ( w->isModified() )
     {
-      if (!w->url().path().isEmpty()) fileWatcher->removeFile(w->url().path());
+      if (!w->isUntitled())
+          fileWatcher->removeFile(w->url().path());
       docTab->showPage(w);
       if ( dont_ask && !w->isUntitled())
       {
-      	w->save();
+        w->save();
         w->closeTempFile();
         w->createTempFile();
-      	if ( w->isModified() ) flagsave = false;
+        if ( w->isModified() ) flagsave = false;
       }
       else
-      	if ( !saveModified() ) flagsave = false;
-       
+        if ( !saveModified() ) flagsave = false;
+
       if (w->url().isLocalFile()) fileWatcher->addFile(w->url().path());
     }
   }
@@ -278,37 +292,41 @@ bool QuantaDoc::saveAll(bool dont_ask)
 
 void QuantaDoc::closeDocument()
 {
-	if (saveModified())
+  if (saveModified())
   {
     Document *w = write();
     w->closeTempFile();
-    if (!w->url().path().isEmpty()) fileWatcher->removeFile(w->url().path());
-  	if ( !quantaApp->view->removeWrite()) openDocument( KURL() );
+    if (!w->isUntitled())
+        fileWatcher->removeFile(w->url().path());
+    if ( !quantaApp->view->removeWrite()) openDocument( KURL() );
   }
 }
 
 void QuantaDoc::closeAll()
 {
+  disconnect( quantaApp->view->writeTab, SIGNAL(currentChanged(QWidget*)), quantaApp, SLOT(slotUpdateStatus(QWidget*)));
   Document *w;
   do
   {
     if (quantaApp->view->writeExists())
     {
-	    if (saveModified() )
+      if (saveModified() )
       {
         w = write();
         w->closeTempFile();
-        if (!w->url().path().isEmpty()) fileWatcher->removeFile(w->url().path());
+        if (!w->isUntitled())
+            fileWatcher->removeFile(w->url().path());
       } else
       {
+        connect( quantaApp->view->writeTab, SIGNAL(currentChanged(QWidget*)), quantaApp, SLOT(slotUpdateStatus(QWidget*)));
         return; //save failed, so don't close anything
       }
     }
-	}
-	while ( quantaApp->view->removeWrite());
-
+  }
+  while ( quantaApp->view->removeWrite());
+  connect( quantaApp->view->writeTab, SIGNAL(currentChanged(QWidget*)), quantaApp, SLOT(slotUpdateStatus(QWidget*)));
   //all documents were removed, so open an empty one
-	openDocument( KURL() );
+  openDocument( KURL() );
 }
 
 void QuantaDoc::readConfig( KConfig *config )
@@ -354,14 +372,13 @@ bool QuantaDoc::saveModified()
       case KMessageBox::Yes :
            if ( write()->isUntitled() )
            {
-             quantaApp->slotFileSaveAs();
+             completed = quantaApp->slotFileSaveAs();
            }
            else
            {
-             saveDocument( write()->url());
-       	   };
+             completed = saveDocument( write()->url());
+            };
 
-           completed=true;
            break;
 
       case KMessageBox::No :
@@ -408,12 +425,12 @@ bool QuantaDoc::isModifiedAll()
 
 void QuantaDoc::setModified(bool flag)
 {
-	write()->setModified(flag);
+  write()->setModified(flag);
 }
 
 Document* QuantaDoc::write()
 {
-	return quantaApp->view->write();
+  return quantaApp->view->write();
 }
 
 
@@ -422,16 +439,26 @@ Document* QuantaDoc::newWrite()
   DTDStruct *dtd = dtds->find(quantaApp->newFileType());
 //  if (!dtd) dtd = dtds->find(qConfig.newFileType);   //fallback, but not really needed
   int i = 1;
-  QString fname;
-  while ( isOpened(fname.sprintf("Untitled%i."+dtd->defaultExtension,i))) i++;
-  
+  while ( isOpened(KURL("file:/"+QString("Untitled%1.").arg(i)+dtd->defaultExtension)))
+  {
+   i++;
+  }
+  QString fname = QString("Untitled%1.").arg(i)+dtd->defaultExtension;
+
   KTextEditor::Document *doc = KParts::ComponentFactory::createPartInstanceFromQuery<KTextEditor::Document>( "KTextEditor/Document",
-													     QString::null,
-													     quantaApp->view->writeTab, 0,
-													     quantaApp->view->writeTab, 0 );
+                               QString::null,
+                               quantaApp->view->writeTab, 0,
+                               quantaApp->view->writeTab, 0 );
 
   Document *w = new Document(quantaApp->projectBaseURL(), doc, quantaApp->getProject(),
                              quantaApp->m_pluginInterface, quantaApp->view->writeTab);
+  QString encoding = quantaApp->defaultEncoding();
+#if KDE_VERSION >= 308
+  dynamic_cast<KTextEditor::EncodingInterface*>(doc)->setEncoding(encoding);
+#else
+  w->kate_doc->setEncoding(encoding);
+#endif
+
   KTextEditor::View * v = w->view();
 
   //[MB02] connect all kate views for drag and drop
@@ -441,7 +468,7 @@ Document* QuantaDoc::newWrite()
   int tabWidth = quantaApp->config->readNumEntry("TabWidth",4);
   quantaApp->config->writeEntry("TabWidth",tabWidth);
   w->readConfig( quantaApp->config );
- 	w->setUntitledUrl( fname );
+   w->setUntitledUrl( fname);
 
   for (unsigned int i=0; i< dynamic_cast<KTextEditor::HighlightingInterface*>(w->doc())->hlModeCount(); i++)
   {
@@ -453,20 +480,20 @@ Document* QuantaDoc::newWrite()
   }
   dynamic_cast<KTextEditor::PopupMenuInterface*>(w->view())->installPopup((QPopupMenu *)quantaApp->factory()->container("popup_editor", quantaApp));
 
- 	quantaApp->setFocusProxy(w->view());
+   quantaApp->setFocusProxy(w->view());
   w->view()->setFocusPolicy(QWidget::WheelFocus);
 /*  quantaApp->setFocusPolicy(QWidget::StrongFocus);
   */
- 	connect( v, SIGNAL(newStatus()),quantaApp, SLOT(slotNewStatus()));
+   connect( v, SIGNAL(newStatus()),quantaApp, SLOT(slotNewStatus()));
 
 /* !!!!
- 	connect( dynamic_cast<KTextEditor::UndoInterface *>(v), SIGNAL(undoChanged()),
+   connect( dynamic_cast<KTextEditor::UndoInterface *>(v), SIGNAL(undoChanged()),
            quantaApp, SLOT(slotNewUndo()) );
 */
 
-// 	connect( w, SIGNAL(statusMsg(const QString &)),quantaApp, SLOT(slotStatusMsg(const QString &)));
+//   connect( w, SIGNAL(statusMsg(const QString &)),quantaApp, SLOT(slotStatusMsg(const QString &)));
 
- 	return w;
+   return w;
 }
 
 /** show popup menu with list of attributes for current tag */
@@ -527,6 +554,10 @@ void QuantaDoc::slotAttribPopup()
         attribMenu->setActiveItem( 0);
 
         QPoint globalPos = w->getGlobalCursorPos();
+        quantaApp->config->setGroup("Kate Document");
+        QFont font;
+        font.fromString(quantaApp->config->readEntry("Font"));
+        globalPos.setY(globalPos.y() + QFontMetrics(font).height());
         attribMenu->exec( globalPos );
       }
     }
@@ -603,13 +634,13 @@ void QuantaDoc::changeFileTabName(KURL newURL)
 {
   Document *w = write();
 
-	if (newURL.isEmpty())
+  if (newURL.isEmpty())
   {
     newURL = w->url();
   }
 
-	if ( quantaApp->view->writeTab->tabToolTip(w) != newURL.prettyURL() )
-	{
+  if ( quantaApp->view->writeTab->tabToolTip(w) != newURL.prettyURL() )
+  {
     quantaApp->view->writeTab->changeTab( w, QExtFileInfo::shortName(newURL.path()) );
     quantaApp->view->writeTab->setTabToolTip( w, newURL.prettyURL() );
   }
@@ -625,15 +656,15 @@ void QuantaDoc::invertSelect(){/*write()->invertSelection();*/}
 void QuantaDoc::slotFileDirty(const QString& fileName)
 {
   Document *w;
-  
+
   QTabWidget *tab = quantaApp->view->writeTab;
   for( int i = 0; i < tab->count(); i++)
   {
     w = dynamic_cast<Document*>(tab->page(i));
-    if ( w->url().path()==fileName )
+    if ( w && w->url().path() == fileName )
     {
       w->setDirtyStatus(true);
-      if (w == write())
+      if (quantaApp->view->writeExists() && w == write())
       {
         w->checkDirtyStatus();
       }
@@ -653,7 +684,7 @@ Document* QuantaDoc::isOpened(const KURL& url)
     {
       w = dynamic_cast<Document*>(tab->page(i));
       break;
-    } 
+    }
   }
   return w;
 }
